@@ -3,6 +3,36 @@ import sys
 import re
 from searcHPV.general import *
 
+#############
+#Function: generate bash script for mapping contigs to human+hpv genome
+#out_dir:out_dir for searcHPV
+#humRef: human reference genome
+#return: path of bash script 
+def mapToRef(out_dir):
+    newRef = f'{out_dir}/hg_hpv.fa'
+    sitesPath = f'{out_dir}/assemble/'
+    listSites = os.listdir(sitesPath)
+    outputPath = f'{out_dir}/call_fusion_virus/'
+    mkdir(outputPath)
+    #if there are sites
+    if listSites != ['']:
+        with open( f'{outputPath}/alignContigsToRef.sh','w') as bashFile:
+            bashFile.write('#!/bin/bash\n')
+            for site in listSites:
+                if ".sh" not in site:
+                    contigPath = f'{sitesPath}/{site}/pearOutput/'            
+                    sitePath = f'{out_dir}/call_fusion_virus/{site}/'
+                    mkdir(sitePath)
+                    bashFile.write( f'''bwa mem -R \'@RG\\tID:hpv\\tSM:hpv\\tLB:hpv\\tPL:ILLUMINA\' -M -t 8 \
+{newRef} {contigPath}/{site}.all.fa.cap.contigs > {sitePath}/{site}.contig.sam;
+samtools view -bhS -@ 8 {sitePath}/{site}.contig.sam > {sitePath}/{site}.contig.bam;
+samtools sort -@ 8 -o {sitePath}/{site}.contig.sort.bam {sitePath}/{site}.contig.bam;
+samtools index {sitePath}/{site}.contig.sort.bam;
+rm {sitePath}/{site}.contig.bam;\n''')
+    return f'{outputPath}/alignContigsToRef.sh'
+
+
+
 
 #############
 #Function: generate bash script for mapping contigs to human genome
