@@ -25,6 +25,9 @@ def main():
     parser.add_argument('-window', type = int, default=300, dest = 'window',
                         help ='the length of region searching for informative reads, default=300', 
                         )
+    parser.add_argument('-clusterWindow', type = int, default=100, dest = 'Clusterwindow',
+                        help ='the length of window of clustering integration sites, default=100', 
+                        )
     parser.add_argument('-gz', action ='store_const', const = True,
                         default = False, dest ='gz', 
                         help ="if fastq files are in gz format")
@@ -57,17 +60,17 @@ def main():
     if args.alignment:
         alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, outputDir = args.outputDir, gz = args.gz)
     elif args.genomeFusion: 
-        genomeFusion(args.window,args.outputDir,args.virRef)
+        genomeFusion(args.clusterWindow,args.outputDir,args.virRef)
     elif args.assemble: 
         #check result from genomeFusion
-        assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz)
+        assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz,args.window)
     elif args.hpvFusion:
         #check result from assemble
         hpv_fusion(args.humRef,args.virRef,args.outputDir)
     else:
         alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, outputDir = args.outputDir, gz = args.gz)
-        genomeFusion(args.window,args.outputDir,args.virRef)
-        assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz)
+        genomeFusion(args.clusterWindow,args.outputDir,args.virRef)
+        assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz,args.window)
         hpv_fusion(args.humRef,args.virRef,args.outputDir)
   
     
\ No newline at end of file
